﻿Imports System
Imports System.IO
Imports System.IO.Pipes
Imports System.Threading.Tasks

Namespace ServerSIP
    Public Class cVaxPipeReadData
        Public m_aDataRead As Byte() = Nothing
        Public m_objPipeClient As cVaxPipeClient = Nothing
    End Class

    '///////////////////////////////////////////////////////////////////////////////////////////////
    '///////////////////////////////////////////////////////////////////////////////////////////////

    Public Interface iVaxPipeClient
        Sub OnVaxPipeClientRecvPCM(objPipeClient As cVaxPipeClient, aDataPCM As Byte(), nSizePCM As Integer)
        Sub OnVaxPipeClientDisconnected(objPipeClient As cVaxPipeClient)
    End Interface

    '///////////////////////////////////////////////////////////////////////////////////////////////
    '///////////////////////////////////////////////////////////////////////////////////////////////

    Public Class cVaxPipeClient

        Private m_objHandlePipe As NamedPipeClientStream = Nothing
        Private m_iPipeClient As iVaxPipeClient

        Public Sub New(iPipeClient As iVaxPipeClient)
            Me.m_iPipeClient = iPipeClient
            Me.m_objHandlePipe = Nothing
        End Sub

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////

        Public Async Function CreatePipeAsyncReadOnly(sPipeName As String) As Task(Of Boolean)

            Me.m_objHandlePipe = New NamedPipeClientStream(".", sPipeName, PipeAccessRights.ReadData Or PipeAccessRights.WriteAttributes, PipeOptions.Asynchronous, System.Security.Principal.TokenImpersonationLevel.None, System.IO.HandleInheritability.None)

            Return Await ConnectPipeAsync()

        End Function

        Public Async Function CreatePipeAsyncReadWrite(sPipeName As String) As Task(Of Boolean)

            Me.m_objHandlePipe = New NamedPipeClientStream(".", sPipeName, PipeAccessRights.ReadWrite Or PipeAccessRights.WriteAttributes, PipeOptions.Asynchronous, System.Security.Principal.TokenImpersonationLevel.None, System.IO.HandleInheritability.None)

            Return Await ConnectPipeAsync()

        End Function

        Private Async Function ConnectPipeAsync() As Task(Of Boolean)

            Try
                Await Me.m_objHandlePipe.ConnectAsync(2000)

                If Not Me.m_objHandlePipe.IsConnected Then
                    ClosePipe()
                    Return False
                End If

                Me.m_objHandlePipe.ReadMode = PipeTransmissionMode.Message
            Catch ex As TimeoutException
                Console.WriteLine("Connection attempt timed out: " & ex.Message)
                ClosePipe()
                Return False
            Catch ex As IOException
                Console.WriteLine("I/O error occurred: " & ex.Message)
                ClosePipe()
                Return False
            Catch ex As Exception
                Console.WriteLine("An unexpected error occurred: " & ex.Message)
                ClosePipe()
                Return False
            End Try

            BeginReadPipe()
            Return True

        End Function

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Sub WriteCallback(asyncResult As IAsyncResult)

        End Sub

        Private Shared Sub ReadCallback(asyncResult As IAsyncResult)
            Dim objReadData As cVaxPipeReadData = DirectCast(asyncResult.AsyncState, cVaxPipeReadData)
            objReadData.m_objPipeClient.OnReadPipeCompleted(asyncResult, objReadData)
        End Sub

        Private Sub OnReadPipeCompleted(asyncResult As IAsyncResult, objReadData As cVaxPipeReadData)

            Dim nReadSize As Integer = Me.m_objHandlePipe.EndRead(asyncResult)

            If nReadSize <= 0 Then
                Me.m_iPipeClient.OnVaxPipeClientDisconnected(Me)
                Return
            End If

            Me.m_iPipeClient.OnVaxPipeClientRecvPCM(Me, objReadData.m_aDataRead, nReadSize)

            BeginReadPipe()

        End Sub

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////

        Private Function BeginReadPipe() As Boolean

            If Me.m_objHandlePipe Is Nothing Then
                Return False
            End If

            Dim objReadData As New cVaxPipeReadData()
            objReadData.m_aDataRead = New Byte(6399) {}
            objReadData.m_objPipeClient = Me

            Dim hResult As IAsyncResult = Me.m_objHandlePipe.BeginRead(objReadData.m_aDataRead, 0, objReadData.m_aDataRead.Length, New AsyncCallback(AddressOf ReadCallback), objReadData)

            Return True

        End Function

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////
        Public Function WritePipe(ByVal aDataPCM As Byte(), ByVal nSizePCM As Integer) As Boolean
            If m_objHandlePipe Is Nothing Then
                Return False
            End If

            Dim aDataWrite As Byte() = New Byte(nSizePCM - 1) {}
            Array.Copy(aDataPCM, aDataWrite, nSizePCM)

            Dim hResult As IAsyncResult = m_objHandlePipe.BeginWrite(aDataWrite, 0, nSizePCM, New AsyncCallback(AddressOf WriteCallback), Nothing)

            Return True
        End Function

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////

        Public Function IsPipeConnected() As Boolean

            If Me.m_objHandlePipe Is Nothing Then
                Return False
            End If

            Return Me.m_objHandlePipe.IsConnected

        End Function

        Public Sub ClosePipe()
            If Me.m_objHandlePipe Is Nothing Then
                Return
            End If

            Me.m_objHandlePipe.Close()
            Me.m_objHandlePipe = Nothing
        End Sub

        '///////////////////////////////////////////////////////////////////////////////////////////////
        '///////////////////////////////////////////////////////////////////////////////////////////////

        ' Uncomment if needed
        '
        ' Public Function CreatePipe(sPipeName As String) As Boolean
        '     Me.m_objHandlePipe = New NamedPipeClientStream(".", sPipeName, PipeAccessRights.ReadData Or PipeAccessRights.WriteAttributes, PipeOptions.Asynchronous, System.Security.Principal.TokenImpersonationLevel.None, System.IO.HandleInheritability.None)
        '     Try
        '         Me.m_objHandlePipe.Connect(3000) ' 3000 ms timeout
        '         Me.m_objHandlePipe.ReadMode = PipeTransmissionMode.Message
        '     Catch ex As TimeoutException
        '         Console.WriteLine("Connection attempt timed out: " & ex.Message)
        '         ClosePipe()
        '         Return False
        '     Catch ex As IOException
        '         Console.WriteLine("I/O error occurred: " & ex.Message)
        '         ClosePipe()
        '         Return False
        '     Catch ex As Exception
        '         Console.WriteLine("An unexpected error occurred: " & ex.Message)
        '         ClosePipe()
        '         Return False
        '     End Try
        '     Return True
        ' End Function

        ' Public Function ReadPipe(aReadBuff As Byte(), nSizeBuff As Integer, ByRef nSizeRead As Integer) As Boolean
        '     If Me.m_objHandlePipe Is Nothing Then
        '         Return False
        '     End If
        '     Dim nRead As Integer = Me.m_objHandlePipe.Read(aReadBuff, 0, nSizeBuff)
        '     If nRead = 0 Then Return False
        '     nSizeRead = nRead
        '     Return True
        ' End Function

    End Class
End Namespace
