Imports ServerSIP.ServerSIP

Public Class LoginForm

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Public Sub New()
        InitializeComponent()
    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub BtnAddLogin_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnAddLogin.Click

        If AddLoginChecks() = False Then Return

        If ComboLogin.FindStringExact(ComboLogin.Text) <> -1 Then
            If MessageBox.Show("Login already exists, do you want to continue?", "VaxVoIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) = DialogResult.No Then
                Return
            End If
        End If

        '//////////////////////////////////////////////////////////////////////////

        Dim sUserPrefix As String = "", sDialPrefix As String = ""
        Dim sToPeerName As String = ""

        GetRouteUI(sUserPrefix, sDialPrefix, sToPeerName)

        '//////////////////////////////////////////////////////////////////////////

        Dim sCodec As String = GetAudioCodecUI()
        Dim nVoiceTypeId As Integer = GetUserTypeUI()

        '//////////////////////////////////////////////////////////////////////////

        If Not cVaxUser.AddUser(ComboLogin.Text, EditPassword.Text, sCodec, CheckBoxBlockAccount.Checked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName) Then
            MessageBox.Show("Login could not be created or Please start the server first.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.[Error])
            Return
        End If

        '//////////////////////////////////////////////////////////////////////////

        If Not ComboLogin.Items.Contains(ComboLogin.Text) Then
            ComboLogin.Items.Add(ComboLogin.Text)
        End If

        MessageBox.Show("Login added/updated successfully.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub BtnRemoveLogin_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnRemoveLogin.Click

        If ComboLogin.Text.Length = 0 Then
            MessageBox.Show("Please enter a login name.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        Dim nIndex As Integer = ComboLogin.FindStringExact(ComboLogin.Text)
        If nIndex = -1 Then Return

        cVaxUser.RemoveUser(ComboLogin.Text)
        ComboLogin.Items.RemoveAt(nIndex)

        ClearDlgUI()

        If ComboLogin.Items.Count > 0 Then
            ComboLogin.SelectedIndex = 0
        End If

        ShowLoginDetails()
        MessageBox.Show("Login removed successfully!", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ComboLogin_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs) Handles ComboLogin.SelectedIndexChanged
        ShowLoginDetails()
    End Sub

    Private Sub BtnClearLogin_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnClearLoginDlg.Click
        ClearDlgUI()
    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub LoadLoginAll()

        ComboLogin.Items.Clear()

        Dim objListUsers As ArrayList = New ArrayList()

        cStoreUser.GetUserAll(objListUsers)
        If objListUsers.Count <= 0 Then Return

        For nIndex As Integer = 0 To objListUsers.Count - 1
            ComboLogin.Items.Add(objListUsers(nIndex))
        Next

        If ComboLogin.Items.Count > 0 Then
            ComboLogin.SelectedIndex = 0
        End If

    End Sub

    Private Sub LoadRouteLineAll()

        Dim objListLines As ArrayList = New ArrayList()

        cStoreLine.GetLineNameAll(objListLines)
        If objListLines.Count <= 0 Then Return

        For nIndex As Integer = 0 To objListLines.Count - 1

            Dim sToPeerName As String = objListLines(nIndex).ToString()
            ComboLoginRoute.Items.Add(sToPeerName)

        Next

        If ComboLoginRoute.Items.Count > 0 Then
            ComboLoginRoute.SelectedIndex = 0
        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Public Sub OnSetActive()

        ComboLoginRoute.Items.Clear()

        LoadLoginAll()
        LoadRouteLineAll()
        ShowLoginDetails()

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ShowLoginDetails()

        Dim sLogin As String = ComboLogin.Text
        If sLogin.Length = 0 Then Return

        Dim sPassword As String = "", sUserPrefix As String = ""
        Dim sDialPrefix As String = "", sAudioCodecList As String = "", sToPeerName As String = ""

        Dim bBlocked As Boolean = True
        Dim nVoiceTypeId As Integer = cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL

        cStoreUser.GetUser(sLogin, sPassword, sAudioCodecList, bBlocked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName)
        UpdateDlgUI(sLogin, sPassword, sAudioCodecList, bBlocked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateDlgUI(ByVal sLogin As String, ByVal sPassword As String, ByVal sAudioCodecList As String, ByVal bBlocked As Boolean, ByVal nVoiceTypeId As Integer, ByVal sUserPrefix As String, ByVal sDialPrefix As String, ByVal sToPeerName As String)

        If sLogin.Length = 0 Then Return

        EditPassword.Text = sPassword
        CheckBoxBlockAccount.Checked = bBlocked

        UpdateUserTypeUI(nVoiceTypeId)
        UpdateAudioCodecUI(sAudioCodecList)

        UpdateRouteUI(sUserPrefix, sDialPrefix, sToPeerName)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateAudioCodecUI(ByVal sAudioCodecList As String)

        ListBoxEnableCodec.Items.Clear()
        ListBoxDisableCodec.Items.Clear()

        For nCount As Integer = 0 To cVaxServerCOM.VAX_CODEC_TOTAL_COUNT - 1
            ListBoxDisableCodec.Items.Add(cCodec.GetCodecName(nCount))
        Next

        Dim sCodecName As String = ""

        For nCount As Integer = 0 To sAudioCodecList.Length - 1
            sCodecName = cCodec.GetCodecName(sAudioCodecList(nCount))

            ListBoxEnableCodec.Items.Add(sCodecName)
            ListBoxDisableCodec.Items.Remove(sCodecName)
        Next

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Function GetAudioCodecUI() As String

        Dim sCodec As String = ""

        For nCount As Integer = 0 To ListBoxEnableCodec.Items.Count - 1
            sCodec += cCodec.GetCodecNo(CStr(ListBoxEnableCodec.Items(nCount)))
        Next

        Return sCodec

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateRouteUI(ByVal sUserPrefix As String, ByVal sDialPrefix As String, ByVal sToPeerName As String)

        EditDialPrefix.Text = sDialPrefix
        EditCallPrefix.Text = sUserPrefix

        Dim nIndex As Integer = ComboLoginRoute.FindStringExact(sToPeerName)

        If nIndex <> -1 Then
            ComboLoginRoute.SelectedIndex = nIndex
        Else
            If ComboLoginRoute.Items.Count > 0 Then ComboLoginRoute.SelectedIndex = 0
        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub GetRouteUI(ByRef sUserPrefix As String, ByRef sDialPrefix As String, ByRef sToPeerName As String)

        Dim nSelectedIndex As Integer = ComboLoginRoute.SelectedIndex

        sUserPrefix = ""
        sDialPrefix = ""
        sToPeerName = ""

        If nSelectedIndex = -1 OrElse EditCallPrefix.Text.Length = 0 Then
            Return
        End If

        sUserPrefix = EditCallPrefix.Text
        sDialPrefix = EditDialPrefix.Text

        sToPeerName = ComboLoginRoute.Text

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateUserTypeUI(ByVal nUserType As Integer)

        If nUserType = cVaxServerCOM.VAX_AUDIO_TYPE_ADMIN Then
            RadioTypeAdmin.Checked = True

        ElseIf nUserType = cVaxServerCOM.VAX_AUDIO_TYPE_USER Then
            RadioTypeAgent.Checked = True

        ElseIf nUserType = cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL Then
            RadioTypeNormal.Checked = True
        Else
            RadioTypeNormal.Checked = True
        End If

    End Sub

    Private Function GetUserTypeUI() As Integer

        If RadioTypeAdmin.Checked = True Then
            Return cVaxServerCOM.VAX_AUDIO_TYPE_ADMIN
        End If

        If RadioTypeAgent.Checked = True Then
            Return cVaxServerCOM.VAX_AUDIO_TYPE_USER
        End If

        If RadioTypeNormal.Checked = True Then
            Return cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL
        End If

        Return cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ClearDlgUI()

        ComboLogin.Text = ""
        EditPassword.Text = ""

        CheckBoxBlockAccount.Checked = False
        RadioTypeNormal.Checked = True

        ListBoxEnableCodec.Items.Clear()
        ListBoxDisableCodec.Items.Clear()

        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G711U)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G711A)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_ILBC)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_GSM610)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G729)

        EditCallPrefix.Text = ""
        EditDialPrefix.Text = ""

        If ComboLoginRoute.Items.Count > 0 Then
            ComboLoginRoute.SelectedIndex = 0
        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Function AddLoginChecks() As Boolean

        If ComboLogin.Text.Length = 0 Then
            MessageBox.Show("Please enter login.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If cVaxDefine.IsDigitAll(ComboLogin.Text) = False Then
            MessageBox.Show("Login should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If EditPassword.Text.Length = 0 Then
            MessageBox.Show("Please enter login password.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If ComboLogin.Text.Length > 20 OrElse EditPassword.Text.Length > 20 Then
            MessageBox.Show("Login && password size should not be more than 20.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If ComboLogin.Text.Substring(0, 2) = "00" Then
            MessageBox.Show("Please do not enter 00 as login prefix. 00 prefix is use to prepare dial plan.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If ListBoxEnableCodec.Items.Count = 0 Then
            MessageBox.Show("Please select a codec.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        Return True

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub BtnDisableCodec_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnDisableCodec.Click

        If ListBoxEnableCodec.SelectedItems.Count = 0 Then Return

        ListBoxDisableCodec.Items.Add(ListBoxEnableCodec.SelectedItem.ToString())
        ListBoxEnableCodec.Items.Remove(ListBoxEnableCodec.SelectedItem)

    End Sub

    Private Sub BtnEnableCodec_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnEnableCodec.Click

        If ListBoxDisableCodec.SelectedItems.Count = 0 Then Return

        ListBoxEnableCodec.Items.Add(ListBoxDisableCodec.SelectedItem.ToString())
        ListBoxDisableCodec.Items.Remove(ListBoxDisableCodec.SelectedItem)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

End Class

