﻿Imports ServerSIP.ServerSIP

Public Class RingGroupForm

    Public Sub New()
        InitializeComponent()
    End Sub

    Private Sub BtnAddRingGroup_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnAddRingGroup.Click

        If ComboRingGroupName.Text = "" OrElse ComboProcessMode.Text = "" Then
            MessageBox.Show("Please fill all values.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        If ComboRingGroupName.FindStringExact(ComboRingGroupName.Text) <> -1 Then
            If MessageBox.Show("Ring Group already exists, do you want to continue?", "VaxVoIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) = DialogResult.No Then
                Return
            End If
        End If

        Dim objAgentList As ArrayList = New ArrayList()
        GetAgentNameAll(objAgentList)

        If Not cVaxRingGroup.AddRingGroup(ComboRingGroupName.Text, GetProcessMode(), GetProcessType(), objAgentList) Then
            MessageBox.Show("Ring Group could not be added/updated or Please start the server first.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        If Not ComboRingGroupName.Items.Contains(ComboRingGroupName.Text) Then
            ComboRingGroupName.Items.Add(ComboRingGroupName.Text)
        End If

        MessageBox.Show("Ring Group added/updated successfully.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
    End Sub

    Private Sub BtnRemoveRingGroup_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnRemoveRingGroup.Click

        If ComboRingGroupName.Text = "" OrElse (Not ComboRingGroupName.Items.Contains(ComboRingGroupName.Text)) Then
            Return
        End If

        Dim nIndex As Integer = ComboRingGroupName.FindStringExact(ComboRingGroupName.Text)
        If nIndex = -1 Then Return

        cVaxRingGroup.RemoveRingGroup(ComboRingGroupName.Text)
        ComboRingGroupName.Items.RemoveAt(nIndex)

        ClearDlgUI()

        If ComboRingGroupName.Items.Count > 0 Then
            ComboRingGroupName.SelectedIndex = 0
        End If

        ShowRingGroupDetails()
        MessageBox.Show("Ring Group removed successfully.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Sub BtnClearRingGroup_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnClearRingGroup.Click
        ClearDlgUI()
    End Sub

    Private Sub BtnAddRingGroupAgent_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnAddAgent.Click

        If ListBoxLogin.FindStringExact(ComboAgentName.Text) <> -1 Then
            Return
        End If

        ListBoxLogin.Items.Insert(0, ComboAgentName.Text)

    End Sub

    Private Sub BtnRemoveRingGroupAgent_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnRemoveAgent.Click
        ListBoxLogin.Items.Remove(ListBoxLogin.SelectedItem)
    End Sub

    Private Sub BtnClearRingGroupAgent_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnClearAgent.Click
        ClearDlgUI()
    End Sub

    Private Sub ClearDlgUI()

        ComboRingGroupName.Text = ""

        If ComboProcessMode.Items.Count > 0 Then
            ComboProcessMode.SelectedIndex = 0
        End If

        If ComboProcessType.Items.Count > 0 Then
            ComboProcessType.SelectedIndex = 0
        End If

        If ComboAgentName.Items.Count > 0 Then
            ComboAgentName.SelectedIndex = 0
        End If

        ListBoxLogin.Items.Clear()

    End Sub

    Private Sub GetAgentNameAll(ByRef objList As ArrayList)
        For Each sAgentName As String In ListBoxLogin.Items
            objList.Add(sAgentName)
        Next
    End Sub

    Private Function GetProcessMode() As Integer

        If ComboProcessMode.SelectedIndex = -1 Then
            MessageBox.Show("Please select a process mode.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return -1
        End If

        Return ComboProcessMode.SelectedIndex

    End Function

    Private Function GetProcessType() As Integer

        If ComboProcessType.SelectedIndex = -1 Then
            MessageBox.Show("Please select a process type.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return -1
        End If

        Return ComboProcessType.SelectedIndex

    End Function

    Private Sub AddProcessMode()

        ComboProcessMode.Items.Clear()

        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_RING_ALL)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_HUNT_RANDOM)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_ROUND_ROBIN)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_LEAST_ANSWERED)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_LEAST_TALK_TIME)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_LONGEST_WAITING)
        ComboProcessMode.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_PRIORITIZED_HUNT)

        ComboProcessMode.SelectedIndex = 0

    End Sub

    Private Sub AddProcessType()

        ComboProcessType.Items.Clear()

        ComboProcessType.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_PROCESS_TYPE_FREE)
        ComboProcessType.Items.Add(cVaxDefine.GROUP_PROCESS_MODE_PROCESS_TYPE_ANY)

        ComboProcessMode.SelectedIndex = 0

    End Sub

    Private Sub AddRingGroups()

        ComboRingGroupName.Items.Clear()

        Dim objList As ArrayList = New ArrayList()
        cStoreRingGroup.GetGroupNameAll(objList)

        If objList.Count <= 0 Then
            Return
        End If

        For Each sGroupName As String In objList
            ComboRingGroupName.Items.Add(sGroupName)
        Next

        If ComboRingGroupName.Items.Count > 0 Then
            ComboRingGroupName.SelectedIndex = 0
        End If

    End Sub

    Private Sub AddUsers()

        ComboAgentName.Items.Clear()

        Dim objList As ArrayList = New ArrayList()
        cStoreUser.GetUserAll(objList)

        If objList.Count <= 0 Then
            Return
        End If

        For nIndex As Integer = 0 To objList.Count - 1
            ComboAgentName.Items.Add(objList(nIndex))
        Next

        If ComboAgentName.SelectedIndex = -1 AndAlso ComboAgentName.Items.Count > 0 Then
            ComboAgentName.SelectedIndex = 0
        End If

    End Sub

    Public Sub OnSetActive()

        AddUsers()

        AddProcessMode()
        AddProcessType()

        AddRingGroups()
        ShowRingGroupDetails()

    End Sub

    Private Sub ComboRingGroupName_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs) Handles ComboRingGroupName.SelectedIndexChanged
        ShowRingGroupDetails()
    End Sub

    Private Sub ShowRingGroupDetails()

        Dim sRingGroupName As String = ComboRingGroupName.Text
        If sRingGroupName.Length = 0 Then Return

        Dim nProcessMode As Integer = -1, nProcessType As Integer = -1
        Dim objAgentList As ArrayList = New ArrayList()

        If Not cStoreRingGroup.GetGroup(sRingGroupName, nProcessMode, nProcessType, objAgentList) Then
            Return
        End If

        If ComboProcessMode.Items.Count > 0 Then
            ComboProcessMode.SelectedIndex = 0
        End If

        If ComboProcessType.Items.Count > 0 Then
            ComboProcessType.SelectedIndex = 0
        End If

        ListBoxLogin.Items.Clear()

        For Each sAgentName As String In objAgentList
            ListBoxLogin.Items.Add(sAgentName)
        Next

    End Sub

End Class


