﻿Imports ServerSIP.ServerSIP

Public Class RoomForm

    Public Sub New()
        InitializeComponent()
    End Sub

    Private Sub OnAddConfRoom(ByVal sender As Object, ByVal e As EventArgs) Handles btnAddRoom.Click

        If Not AddRoomChecks() Then
            Return
        End If

        If ComboRoomName.FindStringExact(ComboRoomName.Text) <> -1 Then
            If MessageBox.Show("Room already exists, do you want to continue?", "VaxVoIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) = DialogResult.No Then
                Return
            End If
        End If

        If Not cVaxRoom.AddRoom(ComboRoomName.Text.Trim(), EditRoomNo.Text.Trim()) Then
            MessageBox.Show("Room could not be added/updated. Please start the server first or can't assign same Dial-in No to multiple rooms.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.[Error])
            Return
        End If

        If Not ComboRoomName.Items.Contains(ComboRoomName.Text) Then
            ComboRoomName.Items.Add(ComboRoomName.Text)
        End If

        MessageBox.Show("Room added/updated successfully.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Sub OnRemoveConfRoom(ByVal sender As Object, ByVal e As EventArgs) Handles btnRemoveRoom.Click

        cVaxRoom.RemoveRoom(ComboRoomName.Text.Trim())

        Dim nIndex As Integer = ComboRoomName.FindStringExact(ComboRoomName.Text)
        If nIndex = -1 Then Return

        cVaxRoom.RemoveRoom(ComboRoomName.Text)
        ComboRoomName.Items.RemoveAt(nIndex)

        ClearDlgUI()

        If ComboRoomName.Items.Count > 0 Then
            ComboRoomName.SelectedIndex = 0
        End If

        ShowRoomDetails()
        MessageBox.Show("Room removed successfully!", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Function AddRoomChecks() As Boolean

        If ComboRoomName.Text.Length = 0 Then
            MessageBox.Show("Please enter Room Name.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If EditRoomNo.Text.Length = 0 Then
            MessageBox.Show("Room No can't be empty.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If cVaxDefine.IsDigitAll(EditRoomNo.Text) = False Then
            MessageBox.Show("Room No should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        Return True

    End Function

    Private Sub ComboRoomName_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs) Handles ComboRoomName.SelectedIndexChanged
        ShowRoomDetails()
    End Sub

    Private Sub ClearDlgUI()
        EditRoomNo.Text = ""
    End Sub

    Private Sub ShowRoomDetails()

        Dim sRoomName As String = ComboRoomName.Text
        If sRoomName.Length = 0 Then Return

        Dim sRoomNo As String = ""
        cStoreRoom.GetRoom(sRoomName, sRoomNo)

        EditRoomNo.Text = sRoomNo

    End Sub

    Private Sub AddRooms()

        ComboRoomName.Items.Clear()

        Dim objList As ArrayList = New ArrayList()
        cStoreRoom.GetRoomNameAll(objList)

        If objList.Count <= 0 Then
            Return
        End If

        For nCount As Integer = 0 To objList.Count - 1
            ComboRoomName.Items.Add(objList(nCount))
        Next

        If ComboRoomName.Items.Count > 0 Then
            ComboRoomName.SelectedIndex = 0
        End If

    End Sub

    Public Sub OnSetActive()
        AddRooms()
        ShowRoomDetails()
    End Sub

End Class
