﻿Imports System
Imports System.Collections

Namespace ServerSIP

    Class cVaxQueue

        Shared m_objQueueList As cVaxQueueList = Nothing

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Sub New()
            If cVaxQueue.m_objQueueList Is Nothing Then cVaxQueue.m_objQueueList = New cVaxQueueList()
        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub ResetAll()
            cVaxQueue.m_objQueueList = New cVaxQueueList()
        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Sub AddQueueList(ByVal sQueueName As String, ByVal sMusicFileName As String, ByVal sDialToneFileName As String)

            cVaxQueue.RemoveQueueList(sQueueName)

            Dim nMusicWaveId As Integer = cVaxServerSIP.mVaxSIP.LoadWaveFile(sMusicFileName)
            Dim nDialToneWaveId As Integer = cVaxServerSIP.mVaxSIP.LoadWaveFile(sDialToneFileName)

            cVaxQueue.m_objQueueList.AddQueue(sQueueName, nMusicWaveId, nDialToneWaveId)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Sub RemoveQueueList(ByVal sQueueName As String)

            Dim nMusicWaveId As Integer = cVaxQueue.m_objQueueList.GetQueueMusicId(sQueueName)
            Dim nDialToneWaveId As Integer = cVaxQueue.m_objQueueList.GetQueueDialToneId(sQueueName)

            cVaxServerSIP.mVaxSIP.UnLoadWaveID(nMusicWaveId)
            cVaxServerSIP.mVaxSIP.UnLoadWaveID(nDialToneWaveId)

            cVaxQueue.m_objQueueList.RemoveQueue(sQueueName)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Sub OnIncomingCall(ByVal nSessionId As Integer, ByVal sCallerName As String, ByVal sCallerId As String, ByVal sQueueName As String, ByRef bProcessed As Boolean)

            bProcessed = False

            If sQueueName.Length = 0 Then Return

            If Not cVaxServerSIP.mVaxSIP.AddCallSessionToQueue(sQueueName, sCallerName, sCallerId, nSessionId, 20) Then
                Return
            End If

            bProcessed = True

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Sub OnQueuePlayWaveStarted(ByVal nEventType As Integer, ByVal sQueueName As String, ByVal nSessionId As Integer)

            If nEventType = cVaxServerCOM.VAX_QUEUE_PLAY_WAVE_EVENT_TYPE_MUSIC Then

                Dim nQueueMusicId As Integer = cVaxQueue.m_objQueueList.GetQueueMusicId(sQueueName)
                If nQueueMusicId = -1 Then Return

                cVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, cVaxServerCOM.VAX_CALL_CHANNEL_ZERO, nQueueMusicId, True, 0)

                Return

            End If

            Dim nQueueDialToneId As Integer = cVaxQueue.m_objQueueList.GetQueueDialToneId(sQueueName)
            If nQueueDialToneId = -1 Then Return

            cVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, cVaxServerCOM.VAX_CALL_CHANNEL_ZERO, nQueueDialToneId, True, 0)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Sub OnQueuePlayWaveEnded(ByVal nEventType As Integer, ByVal sQueueName As String, ByVal nSessionId As Integer)
            cVaxServerSIP.mVaxSIP.PlayWaveStopToCallSession(nSessionId, -1, -1)
        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function AddQueue(ByVal sQueueName As String, ByVal nProcessMode As Integer, ByVal nProcessType As Integer, ByVal objAgentList As ArrayList, ByVal sMusicFileName As String, ByVal sDialToneFileName As String) As Boolean

            If cVaxServerSIP.mVaxSIP.IsInitialized() = False OrElse (sQueueName.Length = 0) Then
                Return False
            End If

            RemoveQueue(sQueueName)

            If Not cVaxServerSIP.mVaxSIP.AddQueue(sQueueName) Then
                Return False
            End If

            For Each sAgentName As String In objAgentList
                cVaxServerSIP.mVaxSIP.AddQueueAgent(sQueueName, sAgentName)
            Next

            cVaxServerSIP.mVaxSIP.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType)

            AddQueueList(sQueueName, sMusicFileName, sDialToneFileName)
            cStoreQueue.AddQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName)

            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub RemoveQueue(ByVal sQueueName As String)

            If cVaxServerSIP.mVaxSIP.IsInitialized() = False OrElse (sQueueName.Length = 0) Then
                Return
            End If

            RemoveQueueList(sQueueName)
            cVaxServerSIP.mVaxSIP.RemoveQueue(sQueueName)
            cStoreQueue.RemoveQueue(sQueueName)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub LoadQueue()

            If Not cVaxServerSIP.mVaxSIP.IsInitialized() Then
                Return
            End If

            Dim objListQueue As ArrayList = New ArrayList()
            cStoreQueue.GetQueueNameAll(objListQueue)

            If objListQueue.Count = 0 Then
                Return
            End If

            Dim objAgentList As ArrayList = New ArrayList()
            Dim sMusicFileName As String = "", sDialToneFileName As String = ""
            Dim nProcessMode As Integer = -1, nProcessType As Integer = -1

            For Each sQueueName As String In objListQueue
                cStoreQueue.GetQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName)
                AddQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName)
            Next

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

    End Class

End Namespace
