﻿Imports System
Imports System.Collections.Generic
Imports System.Collections
Imports System.Linq
Imports System.Text

Namespace ServerSIP

    '////////////////////////////////////////////////////////////////////////////////////////////////////////
    '////////////////////////////////////////////////////////////////////////////////////////////////////////

    Class cVaxUser : Inherits cVaxHashTextData

        Private Shared m_objUserList As cVaxUserList = Nothing
        Private Shared m_nRegisterUserCount As Integer = 0

        Private m_bBlocked As Boolean = False, m_bRegistered As Boolean = False
        Private m_nVoiceTypeId As Integer = cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Sub New(ByVal sUserName As String, ByVal bBlocked As Boolean, ByVal nVoiceTypeId As Integer)

            If cVaxUser.m_objUserList Is Nothing Then
                cVaxUser.m_objUserList = New cVaxUserList()
            End If

            m_bBlocked = bBlocked
            m_nVoiceTypeId = nVoiceTypeId

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub ResetAll()
            m_nRegisterUserCount = 0
            cVaxUser.m_objUserList = New cVaxUserList()
        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Function GetUser(ByVal sUserName As String) As cVaxUser
            Return m_objUserList.GetUser(sUserName)
        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub OnRegisterUser(ByVal sUserLogin As String, ByVal sDomain As String, ByVal sUserAgentName As String, ByVal sFromIP As String, ByVal nFromPort As Integer, ByVal nRegId As Integer)

            Dim objUser As cVaxUser = cVaxUser.GetUser(sUserLogin)

            If objUser Is Nothing Then

                cVaxServerSIP.mVaxSIP.RejectRegister(nRegId, 404, "Not Found")

                Dim sStatus As String = sUserLogin & " " & cVaxDefine.USER_NOT_FOUND
                cVaxServerSIP.mVaxSIP.GenStatusLog(sStatus)

                Return

            End If

            objUser.OnRegister(sUserLogin, nRegId)

        End Sub

        Private Sub OnRegister(ByVal sUserLogin As String, ByVal nRegId As Integer)

            If m_bBlocked Then
                cVaxServerSIP.mVaxSIP.RejectRegister(nRegId, 404, "Not Found")
                Return
            End If

            cVaxServerSIP.mVaxSIP.AuthRegister(nRegId)

            Dim sStatus As String = sUserLogin & " " & cVaxDefine.USER_REG_TRYING
            cVaxServerSIP.mVaxSIP.GenStatusLog(sStatus)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub OnRegisterUserSuccess(ByVal sUserLogin As String, ByVal sFromIP As String, ByVal nFromPort As Integer, ByVal nRegId As Integer)

            Dim objUser As cVaxUser = cVaxUser.GetUser(sUserLogin)
            If objUser Is Nothing Then Return

            objUser.OnRegisterSuccess(sUserLogin)

        End Sub

        Private Sub OnRegisterSuccess(ByVal sUserLogin As String)

            If m_bRegistered = False Then
                m_nRegisterUserCount += 1
            End If

            m_bRegistered = True

            Dim sStatus As String = sUserLogin & " " & cVaxDefine.USER_REG_SUCCESS
            cVaxServerSIP.mVaxSIP.GenStatusLog(sStatus)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub OnRegisterUserFailed(ByVal sUserLogin As String, ByVal sFromIP As String, ByVal nFromPort As Integer, ByVal nRegId As Integer)

            Dim objUser As cVaxUser = cVaxUser.GetUser(sUserLogin)
            If objUser Is Nothing Then Return

            objUser.OnRegisterFailed(sUserLogin)

        End Sub

        Private Sub OnRegisterFailed(ByVal sUserLogin As String)

            Dim sStatus As String = sUserLogin & " " & cVaxDefine.USER_REG_FAILED
            cVaxServerSIP.mVaxSIP.GenStatusLog(sStatus)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub OnUnRegisterUser(ByVal sUserLogin As String)

            Dim objUser As cVaxUser = cVaxUser.GetUser(sUserLogin)
            If objUser Is Nothing Then Return

            objUser.OnUnRegister(sUserLogin)

        End Sub

        Private Sub OnUnRegister(ByVal sUserLogin As String)

            If m_bRegistered = True Then
                m_nRegisterUserCount -= 1
            End If

            m_bRegistered = False

            Dim sStatus As String = sUserLogin & " " & cVaxDefine.USER_UNREGISTER
            cVaxServerSIP.mVaxSIP.GenStatusLog(sStatus)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function AddUser(ByVal sUserName As String, ByVal sPassword As String, ByVal sAudioCodecList As String, ByVal bBlocked As Boolean, ByVal nVoiceTypeId As Integer, ByVal sUserPrefix As String, ByVal sDialPrefix As String, ByVal sToPeerName As String) As Boolean

            If cVaxServerSIP.mVaxSIP.IsInitialized() = False OrElse (sUserName.Length = 0) Then
                Return False
            End If

            RemoveUser(sUserName)

            If Not cVaxServerSIP.mVaxSIP.AddUser(sUserName, sPassword, sAudioCodecList) Then
                Return False
            End If

            cVaxCallSession.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, sToPeerName)
            m_objUserList.AddUser(sUserName, bBlocked, nVoiceTypeId)
            cStoreUser.AddUser(sUserName, sPassword, sAudioCodecList, bBlocked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName)

            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub RemoveUser(ByVal sUserName As String)

            If cVaxServerSIP.mVaxSIP.IsInitialized() = False OrElse (sUserName.Length = 0) Then
                Return
            End If

            cVaxServerSIP.mVaxSIP.RemoveUser(sUserName)
            cVaxCallSession.RemoveUserRoute(sUserName)

            m_objUserList.RemoveUser(sUserName)
            cStoreUser.RemoveUser(sUserName)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub LoadUser()

            If Not cVaxServerSIP.mVaxSIP.IsInitialized() Then
                Return
            End If

            Dim objListUsers As ArrayList = New ArrayList()
            cStoreUser.GetUserAll(objListUsers)

            If objListUsers.Count = 0 Then Return

            Dim sPassword As String = "", sAudioCodecList As String = ""
            Dim sUserPrefix As String = "", sDialPrefix As String = "", sToPeerName As String = ""

            Dim bBlocked As Boolean = False
            Dim nVoiceTypeId As Integer = cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL

            For Each sUserName As String In objListUsers
                cStoreUser.GetUser(sUserName, sPassword, sAudioCodecList, bBlocked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName)
                AddUser(sUserName, sPassword, sAudioCodecList, bBlocked, nVoiceTypeId, sUserPrefix, sDialPrefix, sToPeerName)
            Next

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function IsUserTypeAdmin(ByVal sUserName As String) As Boolean

            Dim objUser As cVaxUser = m_objUserList.GetUser(sUserName)
            If objUser Is Nothing Then Return False

            Return (objUser.m_nVoiceTypeId = cVaxServerCOM.VAX_AUDIO_TYPE_ADMIN)

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function GetVoiceTypeId(ByVal sUserName As String) As Integer

            Dim objUser As cVaxUser = m_objUserList.GetUser(sUserName)
            If objUser Is Nothing Then Return cVaxServerCOM.VAX_AUDIO_TYPE_NORMAL

            Return objUser.m_nVoiceTypeId

        End Function

        Public Shared Function GetRegisteredUserCount() As Integer
            Return m_nRegisterUserCount
        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

    End Class

End Namespace
