﻿Imports System
Imports System.Collections

Namespace ServerSIP

    Class cStoreLine

        Const LINE_ROOT_PATH As String = "Lines\"

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function AddLine(ByVal sLineName As String, ByVal nLineType As Integer, ByVal sAuthUser As String, ByVal sAuthPwd As String, ByVal sServerAddr As String, ByVal nServerPort As Integer, ByVal sAudioCodecList As String, ByVal bRegister As Boolean, ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String, ByVal sQueueName As String, ByVal sRingGroupName As String) As Boolean

            If sLineName.Length = 0 Then Return False

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.SetTEXT(sKeyPath, "LineName", sLineName)
            objStore.SetINT(sKeyPath, "LineType", nLineType)

            objStore.SetTEXT(sKeyPath, "AuthUser", sAuthUser)
            objStore.SetTEXT(sKeyPath, "AuthPwd", sAuthPwd)

            objStore.SetTEXT(sKeyPath, "ServerAddr", sServerAddr)
            objStore.SetINT(sKeyPath, "ServerPort", nServerPort)

            objStore.SetTEXT(sKeyPath, "AudioCodecList", sAudioCodecList)
            objStore.SetBOOL(sKeyPath, "Register", bRegister)

            objStore.Close()

            cStoreLine.AddLineRoute(sLineName, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName)

            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub RemoveLine(ByVal sLineName As String)

            If sLineName.Length = 0 Then Return

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.DeleteSubKey(sKeyPath)
            objStore.Close()

            cStoreLine.RemoveLineRoute(sLineName)

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function GetLine(ByVal sLineName As String, ByRef nLineType As Integer, ByRef sAuthUser As String, ByRef sAuthPwd As String, ByRef sServerAddr As String, ByRef nServerPort As Integer, ByRef sAudioCodecList As String, ByRef bRegister As Boolean, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String, ByRef sQueueName As String, ByRef sRingGroupName As String) As Boolean

            If sLineName.Length = 0 Then Return False

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.GetINT(sKeyPath, "LineType", nLineType, cVaxServerCOM.VAX_LINE_TYPE_UDP)

            objStore.GetTEXT(sKeyPath, "AuthUser", sAuthUser, "")
            objStore.GetTEXT(sKeyPath, "AuthPwd", sAuthPwd, "")

            objStore.GetTEXT(sKeyPath, "ServerAddr", sServerAddr, "")
            objStore.GetINT(sKeyPath, "ServerPort", nServerPort, cVaxServerCOM.SIP_DEFAULT_PORT)

            objStore.GetTEXT(sKeyPath, "AudioCodecList", sAudioCodecList, "")
            objStore.GetBOOL(sKeyPath, "Register", bRegister, False)

            objStore.Close()

            cStoreLine.GetLineRoute(sLineName, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName)

            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Sub GetLineNameAll(ByRef objList As ArrayList)

            objList.Clear()

            Dim sKeyPath As String = LINE_ROOT_PATH
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.EnumSubKeys(sKeyPath, objList)
            objStore.Close()

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Function AddLineRoute(ByVal sLineName As String, ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String, ByVal sQueueName As String, ByVal sRingGroupName As String) As Boolean

            If sLineName.Length = 0 Then Return False

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.SetTEXT(sKeyPath, "ToPeerName", sToPeerName)
            objStore.SetBOOL(sKeyPath, "Rejected", bRejected)

            objStore.SetTEXT(sKeyPath, "RoomName", sRoomName)
            objStore.SetTEXT(sKeyPath, "QueueName", sQueueName)
            objStore.SetTEXT(sKeyPath, "RingGroupName", sRingGroupName)

            objStore.Close()
            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Function GetLineRoute(ByVal sLineName As String, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String, ByRef sQueueName As String, ByRef sRingGroupName As String) As Boolean

            If sLineName.Length = 0 Then Return False

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.GetTEXT(sKeyPath, "ToPeerName", sToPeerName, "")
            objStore.GetBOOL(sKeyPath, "Rejected", bRejected, False)

            objStore.GetTEXT(sKeyPath, "RoomName", sRoomName, "")
            objStore.GetTEXT(sKeyPath, "QueueName", sQueueName, "")

            objStore.GetTEXT(sKeyPath, "RingGroupName", sRingGroupName, "")
            objStore.Close()

            Return True

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Private Shared Sub RemoveLineRoute(ByVal sLineName As String)

            If sLineName.Length = 0 Then Return

            Dim sKeyPath As String = LINE_ROOT_PATH & sLineName
            Dim objStore As cStoreRegistry = New cStoreRegistry()

            objStore.DeleteValue(sKeyPath, "ToPeerName")
            objStore.DeleteValue(sKeyPath, "Rejected")

            objStore.DeleteValue(sKeyPath, "RoomName")
            objStore.DeleteValue(sKeyPath, "QueueName")
            objStore.DeleteValue(sKeyPath, "RingGroupName")

            objStore.Close()

        End Sub

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

        Public Shared Function IsDataStored() As Boolean

            Dim objStore As cStoreRegistry = New cStoreRegistry()

            Dim bResult As Boolean = objStore.IsKeyExist(LINE_ROOT_PATH)
            objStore.Close()

            Return bResult

        End Function

        '////////////////////////////////////////////////////////////////////////////////////////////////////////
        '////////////////////////////////////////////////////////////////////////////////////////////////////////

    End Class

End Namespace
